package handler

import (
	"html/template"
	"net/http"
	"net/http/httptest"
	"strings"
	"testing"
)

func TestArticle(t *testing.T) {
	tests := []struct {
		name string
		id   string
		want int
	}{
		{"success", "1", http.StatusOK},
		{"bad request", "abc", http.StatusBadRequest},
		{"not found", "-1", http.StatusNotFound},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tm := template.Must(template.ParseGlob("../assets/article.html"))
			h := New(nil, tm)

			req := httptest.NewRequest(http.MethodGet, "/articles?id="+tt.id, nil)
			rec := httptest.NewRecorder()
			h.Article(rec, req)

			if rec.Code != tt.want {
				t.Fatalf("want: %d, got: %d", tt.want, rec.Code)
			}

			if rec.Code == http.StatusOK {
				// 記事のタイトルのテスト
				if !strings.Contains(rec.Body.String(), "<h1>") {
					t.Fatal("title is missing")
				}

				// 記事の内容のテスト
				if !strings.Contains(rec.Body.String(), "<p>") {
					t.Fatal("title is missing")
				}
			}
		})
	}
}
