package handler

import (
	"fmt"
	"html/template"
	"net/http"
	"net/http/httptest"
	"strings"
	"testing"
)

func TestHandler_Index(t *testing.T) {
	tm := template.Must(template.ParseGlob("../assets/index.html"))
	h := New(tm, nil)

	req := httptest.NewRequest(http.MethodGet, "/", nil)
	rec := httptest.NewRecorder()
	h.Index(rec, req)

	if rec.Code != http.StatusOK {
		t.Fatal("status code is not 200:", rec.Code)
	}

	// トップページのタイトルのテスト
	if !strings.Contains(rec.Body.String(), "<h1>わたしのブログ</h1>") {
		t.Fatal("title is missing")
	}

	// 記事一覧のテスト
	titles := []string{"自己紹介", "こんなことがありました", "仕事について", "ブログはじめました"}
	for _, title := range titles {
		if !strings.Contains(rec.Body.String(), fmt.Sprintf("<h2>%s</h2>", title)) {
			t.Fatal("article title is missing:", title)
		}
	}
}
